summaryrefslogtreecommitdiffhomepage
path: root/dev/BuildKit/IManifestBuilder.h
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@nekernel.org>2025-07-24 09:15:17 +0100
committerAmlal El Mahrouss <amlal@nekernel.org>2025-07-24 09:15:17 +0100
commita3ea256d00e5aac45574c7c8b076b60630f73a95 (patch)
treed639c686922140ee0465b27964ce4d2b854b68b7 /dev/BuildKit/IManifestBuilder.h
parentbb11d32131e786b40550375005b12bcb31cf25d7 (diff)
feat! refactor! Breaking changes of the NeBuild system.
Working on a TOML backend, refactored source code namespace. And add 'toml++' vendor library. See commit details. Signed-off-by: Amlal El Mahrouss <amlal@nekernel.org>
Diffstat (limited to 'dev/BuildKit/IManifestBuilder.h')
-rw-r--r--dev/BuildKit/IManifestBuilder.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/dev/BuildKit/IManifestBuilder.h b/dev/BuildKit/IManifestBuilder.h
index 065bec3..a0e5d85 100644
--- a/dev/BuildKit/IManifestBuilder.h
+++ b/dev/BuildKit/IManifestBuilder.h
@@ -5,12 +5,11 @@
#pragma once
-#include <BuildKit/Includes.h>
-#include <BuildKit/Macros.h>
+#include <BuildKit/Defines.h>
-#define NEBUILD_MANIFEST_BUILDER : public BTB::IManifestBuilder
+#define NEBUILD_MANIFEST_BUILDER : public NeBuild::IManifestBuilder
-namespace BTB {
+namespace NeBuild {
/// @brief Builder interface class.
/// @note This class is meant to be used as an interface.
class IManifestBuilder {
@@ -29,4 +28,4 @@ class IManifestBuilder {
virtual bool buildTarget(int arg_sz, const char* arg_val, const bool dry_run = false) = 0;
virtual const char* buildSystem() = 0;
};
-} // namespace BTB \ No newline at end of file
+} // namespace NeBuild \ No newline at end of file